.onAttach <- function(libname, pkgname){
  packageStartupMessage("")
  packageStartupMessage("***********************************************************")
  packageStartupMessage("")
  packageStartupMessage("      This is 'SOMbrero' package, v 1.2")
  packageStartupMessage("")
  packageStartupMessage("Citation details with citation('SOMbrero')")
  packageStartupMessage("")
  packageStartupMessage("Further information with help(SOMbrero)...")
  packageStartupMessage("")
  packageStartupMessage("Use sombreroGUI() to start the Graphical Interface.")
  packageStartupMessage("")
  packageStartupMessage("Warning! This package has been implemented (mostly) by girls.")
  packageStartupMessage("Default colors may not be suited for men.")
  packageStartupMessage("")
  packageStartupMessage("***********************************************************")
}
